==> ragel-1.4.1.tar.gz: ragel-1.4.1/tabcodegen.h <==
/*
 *  Copyright 2001, 2002 Adrian Thurston <adriant@ragel.ca>
 */

/*  This file is part of Ragel.
 *
 *  Ragel is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  Ragel is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Ragel; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

#ifndef _TABCODEGEN_H
#define _TABCODEGEN_H

#include <iostream>
#include <fstream>
#include "fsmmachine.h"
#include "parsetree.h"
#include "fsmcodegen.h"

/*
 * TabCodeGen
 */
class TabCodeGen : public FsmCodeGen
{
public:
	TabCodeGen( char *fsmName, FsmMachine *machine,
			ParseData *parseData, ostream &out );
	virtual ~TabCodeGen() { }

protected:
	std::ostream &FUNC_SWITCH();
	std::ostream &INDEX_TYPE();
	std::ostream &KEYS();
	std::ostream &INDICIES();
	std::ostream &STATES();
	std::ostream &TRANSITIONS( int *statePos );
	std::ostream &BSEARCH();
	std::ostream &RANGE_BSEARCH();
	std::ostream &LOCATE_TRANS();

	int makeStateSpec( FsmMachState *state );
	int getStateLen( int stateSpec );
	int *newStatePosArray();

	virtual std::ostream &STATE_OUT_FUNC(FsmMachState *state);
	virtual std::ostream &TRANS_FUNC(FsmMachTrans *trans);
};

/*
 * CTabCodeGen
 */
class CTabCodeGen : public TabCodeGen
{
public:
	CTabCodeGen( char *fsmName, FsmMachine *machine,
			ParseData *parseData, ostream &out );

	/* Write out the C lang header. */
	virtual void writeOutHeader();

	/* Write out the C lang code. */
	virtual void writeOutCode();
};

/*
 * CCTabCodeGen
 */
class CCTabCodeGen : public TabCodeGen
{
public:
	CCTabCodeGen( char *fsmName, FsmMachine *machine,
			ParseData *parseData, ostream &out );

	/* Write out the C++ lang header. */
	virtual void writeOutHeader();

	/* Write out the C++ lang code. */
	virtual void writeOutCode();
};


#endif /* _TABCODEGEN_H */

==> ragel-2.0.tar.gz: ragel-2.0/tabcodegen.h <==
/*
 *  Copyright 2001, 2002 Adrian Thurston <adriant@ragel.ca>
 */

/*  This file is part of Ragel.
 *
 *  Ragel is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  Ragel is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Ragel; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

#ifndef _TABCODEGEN_H
#define _TABCODEGEN_H

#include <iostream>
#include "fsmcodegen.h"

/* Forwards. */
struct FsmMachine;
struct FsmMachState;
struct FsmMachTrans;
struct ParseData;

/*
 * TabCodeGen
 */
class TabCodeGen : public FsmCodeGen
{
public:
	TabCodeGen( char *fsmName, ParseData *parseData, 
			FsmMachine *machine, std::ostream &out );
	virtual ~TabCodeGen() { }

protected:
	std::ostream &FUNC_SWITCH();
	std::ostream &INDEX_TYPE();
	std::ostream &KEYS();
	std::ostream &INDICIES();
	std::ostream &STATES();
	std::ostream &TRANSITIONS( int *statePos );
	std::ostream &BSEARCH();
	std::ostream &RANGE_BSEARCH();
	std::ostream &LOCATE_TRANS();

	int makeStateSpec( FsmMachState *state );
	int getStateLen( int stateSpec );
	int *newStatePosArray();

	virtual std::ostream &STATE_OUT_FUNC(FsmMachState *state);
	virtual std::ostream &TRANS_FUNC(FsmMachTrans *trans);
};

/*
 * CTabCodeGen
 */
class CTabCodeGen : public TabCodeGen
{
public:
	CTabCodeGen( char *fsmName, ParseData *parseData, 
			FsmMachine *machine, std::ostream &out );

	/* Write out the C lang header. */
	virtual void writeOutHeader();

	/* Write out the C lang code. */
	virtual void writeOutCode();
};

/*
 * CCTabCodeGen
 */
class CCTabCodeGen : public TabCodeGen
{
public:
	CCTabCodeGen( char *fsmName, ParseData *parseData, 
			FsmMachine *machine, std::ostream &out );

	/* Write out the C++ lang header. */
	virtual void writeOutHeader();

	/* Write out the C++ lang code. */
	virtual void writeOutCode();
};


#endif /* _TABCODEGEN_H */
